[PATCH] D114834: [clang][PR52088]Fix assertion failure when passing bool as the type of next parameter

Lucas Wang via Phabricator via cfe-commits cfe-commits at lists.llvm.org
Tue Nov 30 19:28:18 PST 2021


Lucas updated this revision to Diff 390889.
Lucas added a comment.

Include all local changes.


Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D114834/new/

https://reviews.llvm.org/D114834

Files:
  clang/lib/Sema/SemaExpr.cpp
  clang/test/SemaCXX/varargs.cpp


Index: clang/test/SemaCXX/varargs.cpp
===================================================================
--- clang/test/SemaCXX/varargs.cpp
+++ clang/test/SemaCXX/varargs.cpp
@@ -53,6 +53,8 @@
 
   // Ensure that signed vs unsigned doesn't matter either.
   (void)__builtin_va_arg(ap, unsigned int);
+
+  (void)__builtin_va_arg(ap, bool); // expected-warning {{second argument to 'va_arg' is of promotable type 'bool'; this va_arg has undefined behavior because arguments will be promoted to 'int'}}
 }
 
 #if __cplusplus >= 201103L
Index: clang/lib/Sema/SemaExpr.cpp
===================================================================
--- clang/lib/Sema/SemaExpr.cpp
+++ clang/lib/Sema/SemaExpr.cpp
@@ -15902,9 +15902,9 @@
 
       // If the types are still not compatible, we need to test whether the
       // promoted type and the underlying type are the same except for
-      // signedness. Ask the AST for the correctly corresponding type and see
-      // if that's compatible.
-      if (!PromoteType.isNull() &&
+      // signedness except for boolean. Ask the AST for the correctly
+      // corresponding type and see if that's compatible.
+      if (!PromoteType.isNull() && !UnderlyingType->isBooleanType() &&
           PromoteType->isUnsignedIntegerType() !=
               UnderlyingType->isUnsignedIntegerType()) {
         UnderlyingType =


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D114834.390889.patch
Type: text/x-patch
Size: 1360 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/cfe-commits/attachments/20211201/7f563879/attachment.bin>


More information about the cfe-commits mailing list